Re: [PATCH] virtio: fix virtio_config_ops kerneldocs

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Il 20/12/22 08:37, Ricardo Cañuelo ha scritto:
Fixes two warning messages when building htmldocs:

     warning: duplicate section name 'Note'
     warning: expecting prototype for virtio_config_ops().
              Prototype was for vq_callback_t() instead

Signed-off-by: Ricardo Cañuelo <ricardo.canuelo@xxxxxxxxxxxxx>
---
  include/linux/virtio_config.h | 9 +++++----
  1 file changed, 5 insertions(+), 4 deletions(-)

diff --git a/include/linux/virtio_config.h b/include/linux/virtio_config.h
index 4b517649cfe8..f9a33062c089 100644
--- a/include/linux/virtio_config.h
+++ b/include/linux/virtio_config.h
@@ -16,8 +16,10 @@ struct virtio_shm_region {
  	u64 len;
  };
+typedef void vq_callback_t(struct virtqueue *);
+
  /**
  * virtio_config_ops - operations for configuring a virtio device
   * Note: Do not assume that a transport implements all of the operations
   *       getting/setting a value as a simple read/write! Generally speaking,
   *       any of @get/@set, @get_status/@set_status, or @get_features/
@@ -68,8 +70,8 @@ struct virtio_shm_region {
   * @finalize_features: confirm what device features we'll be using.
   *	vdev: the virtio_device
   *	This sends the driver feature bits to the device: it can change
- *	the dev->feature bits if it wants.
- * Note: despite the name this can be called any number of times.
+ *	the dev->feature bits if it wants. Note: despite the name this
+ *	can be called any number of times.
@@ -16,8 +16,10 @@ struct virtio_shm_region {
  /**
- * virtio_config_ops - operations for configuring a virtio device
+ * struct virtio_config_ops - operations for configuring a virtio device
   * Note: Do not assume that a transport implements all of the operations
   *       getting/setting a value as a simple read/write! Generally speaking,

To avoid getting the same warning in the future (developer mistake and/or other
reasons), what about dropping this instance of "Note:" entirely?

I think that something like...

the dev->feature bits if it wants. Note that despite the name....

Cheers,
Angelo




[Index of Archives]     [Linux Kernel]     [Linux USB Development]     [Yosemite News]     [Linux SCSI]

  Powered by Linux